@@ -1118,10 +1118,11 @@ class State:
 class StateMachineAPI:
     def __init__(self, app):
         self.App = app
+        self.StateType = StateType
         self.SequenceApi = self.App.Sequence
-        self.CurrentState = StateType.FIRST_ENTRY.value
-        self.States: List[State] = []
+        self.STATES = []
         self._lock = Lock()
+        self.sSTATE = self.StateType.FIRST_ENTRY.value
         
    #? Single State Functions
     
@@ -2271,7 +2272,7 @@ class Api:
             ```
             # Details
             Last Updated: 05.10.25
-            Version: v3.0.2
+            Version: v3.0.5
             Api-Reference: https://pypi.org/project/toolos/
             Author: Lilias Hatterscheidt
             Copyright © 2025 ClayTechnologie. All rights reserved.
@@ -2552,6 +2553,8 @@ class Driver(Api):
 #         "PACKAGEPATH": "./packages",
 #         "LOGPATH": "./logs"
 #         })
-    
+#     if app.StateMachine.sIsState(app.StateMachine.StateType.FIRST_ENTRY.value):
+#         print("First Entry State")
+        
 # if __name__ == "__main__":
 #     test()
\ No newline at end of file
